This uses `mkdocs` to turn docstrings into html pages, to be served at lancedb.github.io/geneva/api.

To start:

1. install dependencies using either `uv sync --extra docs` (though this may uninstall a lot of deps that are used in the rest of this repo but not in the docs) or:

    ```
    pip install mkdocs mkdocs-material "mkdocstrings[python]"
    ``` 

2. from `../`: `make docs`.

Then open them in at localhost:8000. Unfortunately it doesn't hot reload, so when you make a change, you have to stop and restart the server.
